@@ -5,28 +5,28 @@ from ._app import get_app_config
 __all__ = ['create_response', 'get_status_msg', 'ResponseManager']
 
 
-def create_response(success, data, wrapper=False):
+def create_response(success, data, data_wrapped=False):
     """
     Create the response json result.
     :param success:
     :param data:
-    :param wrapper:
+    :param data_wrapped:
     :return:
     """
     if success is True:
-        return _create_success_response(data, wrapper)
+        return _create_success_response(data, data_wrapped)
     else:
         return _create_fail_response(data)
 
 
-def _create_success_response(data, wrapper=False):
+def _create_success_response(data, data_wrapped=False):
     """
     :param data:
-    :param wrapper:
+    :param data_wrapped:
     :return:
     """
-    status = get_app_config('FLASKZ_RES_SUCCESS_STATUS')
-    if wrapper is True:
+    status = get_app_config('FLASKZ_RES_SUCCESS_STATUS') or 'success'
+    if data_wrapped is True:
         _data = {
             'status': status,
         }
@@ -45,7 +45,7 @@ def _create_fail_response(status_code, msg=None):
     :param status_code:
     :return:
     """
-    status = get_app_config('FLASKZ_RES_FAIL_STATUS')
+    status = get_app_config('FLASKZ_RES_FAIL_STATUS') or 'fail'
     msg = msg or get_status_msg(status_code)
 
     if type(status_code) == tuple:
